==> rutorrent-3.9.tar.gz: ruTorrent-3.9/plugins/extsearch/lang/fr.js <==
﻿/*
 * PLUGIN EXTSEARCH
 *
 * French language file.
 *
 * Author: Nicobubulle (nicobubulle@gmail.com)
 */

 theUILang.tegMenuLoad			= "Télécharger";
 theUILang.tegMenuOpen			= "Ouvrir dans le navigateur";
 theUILang.tegMenuDeleteItem		= "Supprimer";
 theUILang.tegMenuDelete		= "Supprimer la recherche";
 theUILang.tegRefresh			= "Rafraichir la recherche";
 theUILang.exsGlobal			= "Inclure dans la catégorie 'Tous les ...'";
 theUILang.exsLimit			= "Limite des résultats";
 theUILang.exsEngines			= "Moteurs";
 theUILang.exsSearch			= "Recherche";
 theUILang.exsGlobalLimit		= "Limitations communes";
 theUILang.excat			= "Catégories";
 theUILang.excatall			= "Tous";
 theUILang.excatmovies			= "Films";
 theUILang.excattv			= "TV";
 theUILang.excatmusic			= "Musiques";
 theUILang.excatgames			= "Jeux";
 theUILang.excatanime			= "Anime";
 theUILang.excatsoftware		= "Logiciels";
 theUILang.excatpictures		= "Photos";
 theUILang.excatbooks			= "Livres";
 theUILang.extPrivate			= "Privé";
 theUILang.extPublic			= "Public";
 theUILang.exsCookies			= "Format du cookie";
 theUILang.extAllPublic 		= "Tous les publics";
 theUILang.extAllPrivate		= "Tous les privés";
 theUILang.exsMustInstallCookies	= "Vous devez installer le plug-in 'Cookies' pour fonctionner avec ce moteur de recherche.";
 theUILang.exsMustInstallLoginMgr	= "Vous devez installer le plug-in 'LoginMgr' pour fonctionner avec ce moteur de recherche.";
 theUILang.exsLoginMgr			= "Configurez votre compte dans le plug-in 'LoginMgr' pour fonctionner avec ce moteur de recherche.";
 theUILang.exsURLInfo			= "Info URL";
 theUILang.exsURLGUID			= "URL de la description";
 theUILang.exsURLHref			= "URL à charger";


thePlugins.get("extsearch").langLoaded();

==> rutorrent-4.3.5.tar.gz: ruTorrent-4.3.5/plugins/extsearch/lang/fr.js <==
﻿/*
 * PLUGIN EXTSEARCH
 *
 * French language file.
 *
 * Author: Nicobubulle (nicobubulle@gmail.com)
 */

 theUILang.tegMenuLoad			= "Télécharger";
 theUILang.tegMenuOpen			= "Ouvrir dans le navigateur";
 theUILang.tegMenuDeleteItem		= "Supprimer";
 theUILang.tegMenuDelete		= "Supprimer la recherche";
 theUILang.tegRefresh			= "Rafraichir la recherche";
 theUILang.exsGlobal			= "Inclure dans la catégorie 'Tous les...'";
 theUILang.exsLimit			= "Limite des résultats";
 theUILang.exsEngines			= "Moteurs";
 theUILang.exsSearch			= "Recherche";
 theUILang.exsGlobalLimit		= "Limitations communes";
 theUILang.excat			= "Catégories";
 theUILang.excatall			= "Tous";
 theUILang.excatmovies			= "Films";
 theUILang.excattv			= "TV";
 theUILang.excatmusic			= "Musiques";
 theUILang.excatgames			= "Jeux";
 theUILang.excatanime			= "Anime";
 theUILang.excatsoftware		= "Logiciels";
 theUILang.excatpictures		= "Photos";
 theUILang.excatbooks			= "Livres";
 theUILang.extPrivate			= "Privé";
 theUILang.extPublic			= "Public";
 theUILang.exsCookies			= "Format du cookie";
 theUILang.extAllPublic			= "Tous les publics";
 theUILang.extAllPrivate		= "Tous les privés";
 theUILang.exsMustInstallCookies	= "Vous devez installer le plugin 'Cookies' pour pouvoir utiliser ce moteur de recherche.";
 theUILang.exsMustInstallLoginMgr	= "Vous devez installer le plugin 'LoginMgr' pour pouvoir utiliser ce moteur de recherche.";
 theUILang.exsLoginMgr			= "Configurez votre compte dans le plugin 'LoginMgr' pour pouvoir utiliser ce moteur de recherche.";
 theUILang.exsURLInfo			= "Info URL";
 theUILang.exsURLGUID			= "URL de la description";
 theUILang.exsURLHref			= "URL à charger";

thePlugins.get("extsearch").langLoaded();
